<?php
/* 
 * カテゴリ毎にコンテンツを設定する事ができます。
 */
class CategoryContents extends SC_Plugin_Base {

    /**
     * コンストラクタ
     *
     */
    public function __construct(array $arrSelfInfo) {
        parent::__construct($arrSelfInfo);
    }

    /**
     * インストール
     * installはプラグインのインストール時に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin plugin_infoを元にDBに登録されたプラグイン情報(dtb_plugin)
     * @return void
     */
    function install($arrPlugin, $objPluginInstaller) {
    	$objPluginInstaller->sqlAterTableAdd("dtb_category", "plg_categorycontents_category_contents", "TEXT");
    	$objPluginInstaller->sqlAterTableAdd("dtb_category", "plg_categorycontents_category_contents", "TEXT");

        // INSERTの実行
        $sqlval = array();
        $sqlval['dummy'] = "test";
        $objPluginInstaller->sqlInsert('dtb_test', $sqlval);
        
        if(copy(PLUGIN_UPLOAD_REALDIR . "CategoryContents/logo.png", PLUGIN_HTML_REALDIR . "CategoryContents/logo.png") === false);
    }
    /**
     * アンインストール
     * uninstallはアンインストール時に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     * 
     * @param array $arrPlugin プラグイン情報の連想配列(dtb_plugin)
     * @return void
     */
    function uninstall($arrPlugin, $objPluginInstaller) {
        $objPluginInstaller->sqlAterTableDrop("dtb_category", "plg_categorycontents_category_contents");
        // INSERTの実行
        $sqlval = array();
        $sqlval['dummy'] = "test2";
        $objPluginInstaller->sqlUpdate('dtb_test', $sqlval);
    }
    
    /**
     * 稼働
     * enableはプラグインを有効にした際に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin プラグイン情報の連想配列(dtb_plugin)
     * @return void
     */
    function enable($arrPlugin) {
        // nop
    }

    /**
     * 停止
     * disableはプラグインを無効にした際に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin プラグイン情報の連想配列(dtb_plugin)
     * @return void
     */
    function disable($arrPlugin) {
        // nop
    }

    /**
     * カテゴリ毎にコンテンツの登録をします.
     * @param LC_Page_Admin_Products_Category $objPage <管理画面>カテゴリ登録.
     * @return void
     */
    function contents_set($objPage) {
        $post = $_POST;
        switch ($post['mode']) {
            // 編集押下時
            case 'pre_edit':
                $category_id = $objPage->arrForm['category_id'];
                $array_category = CategoryContents::getCategoryByCategoryId($category_id);
                $objPage->arrForm['plg_categorycontents_category_contents'] = $array_category['plg_categorycontents_category_contents'];
                var_dump($array_category);
                break;
            // 登録押下時
            case 'edit':
                $category_id = $post['category_id'];
                $category_contents = $post['plg_categorycontents_category_contents'];
                // 新規登録
                if(empty($category_id)){
                    $category_name = $post['category_name'];
                    $array_category = CategoryContents::getCategoryByCategoryName($category_name);
                    $category_id = $array_category['category_id'];
                }
                CategoryContents::updateCategoryContents($category_id,$category_contents);
                break;
            default:
                break;
        }
    }

    /**
     * 商品一覧でカテゴリが指定されている場合に登録されているコンテンツを表示します.
     * 
     * @param LC_Page_Products_List $objPage 
     * @return void
     */
    function disp_contents($objPage) {
        $category_id = $objPage->arrSearchData['category_id'];
        if(!empty($category_id)){
            $array_category = CategoryContents::getCategoryByCategoryId($category_id);
            $objPage->plg_categorycontents_category_contents = $array_category['plg_categorycontents_category_contents'];
        }
    }
    
    /**
     * プレフィルタコールバック関数
     *
     * @param string &$source テンプレートのHTMLソース
     * @param LC_Page_Ex $objPage ページオブジェクト
     * @param string $filename テンプレートのファイル名
     * @return void
     */
    function prefilterTransform(&$source, LC_Page_Ex $objPage, $filename) {
        $objTransform = new SC_Helper_Transform($source);
        $template_dir = PLUGIN_UPLOAD_REALDIR . 'CategoryContents/templates/';
        switch($objPage->arrPageLayout['device_type_id']){
            case DEVICE_TYPE_MOBILE:
            case DEVICE_TYPE_SMARTPHONE:
            case DEVICE_TYPE_PC:
                // 商品一覧画面
                if (strpos($filename, 'products/list.tpl') !== false) {
                    $objTransform->select('h2.title')->insertBefore(file_get_contents($template_dir . 'snip_products_list_add.tpl'));
                }
                break;
            case DEVICE_TYPE_ADMIN:
            default:
                // カテゴリ登録画面
                if (strpos($filename, 'products/category.tpl') !== false) {
                    $objTransform->select('div.now_dir')->replaceElement(file_get_contents($template_dir . 'snip.admin_basis_category_add.tpl'));
                }
                break;
        }
        $source = $objTransform->getHTML();
    }
    

    /**
     * 処理の介入箇所とコールバック関数を設定
     * registerはプラグインインスタンス生成時に実行されます
     * 
     * @param SC_Helper_Plugin $objHelperPlugin 
     * @return void
     */
    function register(SC_Helper_Plugin $objHelperPlugin) {
        $objHelperPlugin->addAction('LC_Page_Admin_Products_Category_action_after', array($this, 'contents_set'));
        $objHelperPlugin->addAction('LC_Page_Products_List_action_after', array($this, 'disp_contents'));
        $objHelperPlugin->addAction('prefilterTransform', array(&$this, 'prefilterTransform'), 1);
    }

    /**
     * カテゴリIDからカテゴリ情報を取得します
     * 
     * @param int $category_id カテゴリID
     * @return array カテゴリ情報
     */
    function getCategoryByCategoryId ($category_id) {
        $objQuery =& SC_Query_Ex::getSingletonInstance();
        $array_categorys = $objQuery->select("*", "dtb_category", "category_id = ?", array($category_id));
        return $array_categorys[0];
    }

    /**
     * カテゴリ名からカテゴリ情報を取得します
     * 
     * @param string $category_name カテゴリ名
     * @return array カテゴリ情報
     */
    function getCategoryByCategoryName ($category_name) {
        $objQuery =& SC_Query_Ex::getSingletonInstance();
        $array_categorys = $objQuery->select("*", "dtb_category", "category_name = '". $category_name. "'");
        return $array_categorys[0];
    }
    
    /**
     * dtb_categoryのcategory_contentsを更新します.
     * 
     * @param int $category_id カテゴリID
     * @param string $category_contents カテゴリコンテンツ
     * @return void
     */
    function updateCategoryContents ($category_id, $category_contents) {
        $objQuery =& SC_Query_Ex::getSingletonInstance();
        $sqlval = array();
        $sqlval['plg_categorycontents_category_contents'] = $category_contents;
        $sqlval['update_date'] = 'CURRENT_TIMESTAMP';
        $objQuery->update("dtb_category", $sqlval, "category_id = ?", array($category_id));        
    }
}

?>
